import Layout from '../../components/Layout'
import Head from 'next/head'

export default () => (
  <Layout>
    <Head>
      <title>Liara | رابط خط فرمان - Liara CLI</title>
    </Head>

    <h1>رابط خط فرمان (CLI)</h1>

    <p>
      رابط خط فرمان و یا همان CLI لیارا، این امکان را به شما می‌دهد که فقط با چند دستور ساده، اپلیکیشن خود را در بستر ابری ما مستقر کنید.
      اگر با محیط خط فرمان و ترمینال آشنایی ندارید، نگران نباشید. دستوراتی که برای کار با لیارا نیاز خواهید داشت، بسیار مختصر و کوتاه هستند و نیاز به دانش عمیقی ندارند.
    </p>
    
    <h3>نصب و راه‌اندازی</h3>
    <p>
      برای نصب، NodeJS و npm باید در کامپیوتر شما نصب شده‌باشند. پیشنهاد ما نسخه‌ی ۸ به بعد NodeJS است.
      <br/>
      برای دانلود و نصب NodeJS می‌توانید از لینک مقابل استفاده کنید:
      {' '}
      <a href="https://nodejs.org/en/">وب‌سایت رسمی NodeJS</a>
    </p>
    <p>
      بعد از نصب NodeJS، با استفاده از دستور زیر، CLI بر روی کامپیوتر شما نصب می‌گردد:
    </p>
    <pre>
      <code>
        npm install -g @liara/cli
      </code>
    </pre>
    <h3>ورود به حساب کاربری</h3>
    <p>
      برای این‌که بتوانید از CLI استفاده کنید، لازم است که در ابتدا، با استفاده از اطلاعات حساب کاربری‌تان در لیارا، وارد شوید:
    </p>
    <pre>
      <code>
        liara login
      </code>
    </pre>
    <p>
      بعد از وارد کردن دستور بالا، باید ایمیل و رمز عبور کاربری که با آن در لیارا ثبت نام کرده‌اید را وارد کنید.
      <br/>
      اگر اطلاعات صحیح باشند، با موفقیت وارد خواهید شد و CLI قابل استفاده خواهد بود.
      <br/>
      اگر هنوز ثبت نام نکرده‌اید، می‌توانید از لینک رو به رو اقدام کنید:
      {' '}
      <a href="https://console.liara.ir/register">ثبت نام در لیارا</a>
    </p>
    <h3>فایل liara.json</h3>
    <p>
      برای این‌که CLI بتواند پروژه‌ی شما را با موفقیت در بستر لیارا مستقر کند، نیاز دارد که اطلاعاتی از پروژه‌ی‌تان داشته‌باشد.
      شما می‌توانید با ایجاد یک فایل با نام <span className="code">liara.json</span> این اطلاعات را در اختیار CLI قرار بدهید.
    </p>
    <h3>نمونه‌ای از فایل liara.json:</h3>
    <pre>
      <code>
{`{
  "platform": "node",
  "project": "my-project",
  "port": 3000
}`}
      </code>
    </pre>
    <p>
      همان‌طور که مشاهده می‌کنید، فیلد project 
      در این فایل، همان شناسه‌ی پروژه‌ای است که می‌خواهید روی آن دیپلوی کنید.
      در این نمونه، فرض شده‌است که پروژه با NodeJS نوشته شده‌است.
      به همین دلیل، برای اجرای این پروژه نیاز به پلتفرم
      <span className="code">node</span>
      وجود دارد.
      در حال حاظر، پلتفرم‌های زیر قابل استفاده هستند:
    </p>
    <div className="ltr">
      <ul>
        <li>node</li>
        <li>laravel</li>
        <li>static</li>
        <li>angular</li>
        <li>wordpress</li>
        <li>docker</li>
      </ul>
    </div>
    <p>
      <b>نکته: </b>
      برای هر پلتفرم، تنظیمات جداگانه‌ای وجود دارد که در بخش مربوط به هر کدام، می‌توانید مشاهده کنید.
    </p>

    <h3>مستقر کردن پروژه‌ها</h3>
    <p>
      برای مستقر کردن یک پروژه، باید دایرکتوری فعلی‌تان را به پوشه‌ی مورد نظر تغییر داده و بعد دستور
      <span className="code">liara deploy</span>
      را وارد کنید.
    </p>
    <pre>
      <code>
{`$ cd projects/my-project
$ liara deploy
`}
      </code>
    </pre>

    <p>
      بدون تغییر دادن دایرکتوری فعلی هم می‌توانید با پاس دادن پارامتر
      <span className="code">--path</span>
      پروژه‌ی مورد نظرتان را روی سرورهای لیارا مستقر کنید.
    </p>
    <pre>
      <code>
      $  liara deploy --path projects/my-project
      </code>
    </pre>

    <p>
      بعد از این دستور، لیارا سعی می‌کند که نوع پروژه‌ی شما را تشخیص دهد تا بتواند بستر مناسب
      برای اجرای آن را فراهم کند. مثلا اگر پروژه‌ی شما با Laravel نوشته شده‌است،
      در ابتدا سعی می‌کند که تشخیص دهد پروژه‌ی شما یک پروژه‌ی لاراولی است و در مرحله‌ی بعد از
      طریق راه‌اندازی بستر مناسب برای اجرای لاراول مانند نصب کردن PHP و Apache
      پروژه‌ی شما را اجرا می‌کند.
    </p>

    <h3>عملیات استقرار بدون فایل liara.json:</h3>
    <p>
      <p>
        ایجاد فایل liara.json الزامی نیست. شما می‌تونید از طریق پرامترهایی مثل
        <span className="code">--project</span>
        و یا
        <span className="code">--port</span>
        پروژه و پورت مدنظرتان را مشخص کنید. در این صورت دیگر
        cli
        سوالی در این باره از شما نمی‌پرسد.
      </p>
      <pre>
        <code>
          $ liara deploy --project my-project --port 5000
        </code>
      </pre>
    </p>

    <h3>نمایش لاگ‌های پروژه بلافاصله بعد از اتمام استقرار</h3>
    <p>
      بعد از اجرای دستوری
      <span className="code">liara deploy</span>،
      اگر عملیات با موفقیت به اتمام برسد، لیارا لاگ‌های پروژه‌ی‌تان را بلافاصله بعد از اتمام استقرار نمایش می‌دهد.
      با مشاهده‌ی لاگ‌ها می‌توانید مطمئن شوید که پروژه‌ی‌تان به درستی مستقر شده.
      اگر نیازی به این قابلیت نمی‌بینید و یا این که دستور liara deploy
      را در محیط CI / CD
      اجرا می‌کنید، می‌توانید با پارامتر
      <span className="code">--no-project-logs</span>
      این قابلیت را غیر فعال کنید.
    </p>
  </Layout>
)